
# $rcs = ' $Id: News.pm,v 1.10 2008/05/06 02:17:38 Martin Exp $ ' ;

=head1 NAME

WWW::Search::News - WWW::Search backend for news searches

=head1 DESCRIPTION

This is an empty package.  It only exists so that CPAN users can say
"install WWW::Search::News" and they'll get what they expect.  Well,
actually I'm not sure what they expect, but they'll get something
reasonable.

I also use it to control the version number of the distribution.

=head1 SEE ALSO

  WWW::Search::AP
  WWW::Search::Reuters
  WWW::Search::WashPost

=head1 AUTHOR

Martin Thurn <mthurn@cpan.org>

=head1 LICENSE

This software is released under the same license as Perl itself.

=cut

package WWW::Search::News;

use strict;
use warnings;

use 5.005;

our
$VERSION = '1.077';

1;

__END__

